@@ -48,6 +48,9 @@ requests.put = _put
 requests.delete = _delete
 requests.options = _options
 
+def _total_seconds(td):
+    return (td.microseconds + (td.seconds + td.days * 24 * 3600) * 10**6) / 10**6
+
 class RequestsDebugPanel(Panel):
     """
     Panel that displays queries made by Requests backends.
@@ -68,7 +71,7 @@ class RequestsDebugPanel(Panel):
 
     def nav_subtitle(self):
         print(self.queries)
-        return "%s queries in %.2fs" % (len(self.queries), sum([q.elapsed.total_seconds() for q in self.queries]))
+        return "%s queries in %.2fs" % (len(self.queries), sum([_total_seconds(q.elapsed) for q in self.queries]))
 
     def url(self):
         return ''
